@@ -20,7 +20,6 @@
 
 
 require_once dirname(__FILE__).'/include/config.inc.php';
-require_once dirname(__FILE__).'/include/hostgroups.inc.php';
 require_once dirname(__FILE__).'/include/hosts.inc.php';
 require_once dirname(__FILE__).'/include/items.inc.php';
 require_once dirname(__FILE__).'/include/forms.inc.php';
@@ -331,12 +330,13 @@ $fields = [
 	'subfilter_interval' =>			[T_ZBX_STR, O_OPT, null,	null,		null],
 	'subfilter_history' =>			[T_ZBX_STR, O_OPT, null,	null,		null],
 	'subfilter_trends' =>			[T_ZBX_STR, O_OPT, null,	null,		null],
+	'checkbox_hash' =>				[T_ZBX_STR, O_OPT, null,	null,		null],
 	// sort and sortorder
 	'sort' =>						[T_ZBX_STR, O_OPT, P_SYS,
 										IN('"delay","history","key_","name","status","trends","type"'),
 										null
 									],
-	'sortorder' =>					[T_ZBX_STR, O_OPT, P_SYS, IN('"'.ZBX_SORT_DOWN.'","'.ZBX_SORT_UP.'"'),	null]
+	'sortorder' =>					[T_ZBX_STR, O_OPT, P_SYS, IN('"'.ZBX_SORT_DOWN.'","'.ZBX_SORT_UP.'"'), null]
 ];
 
 $valid_input = check_fields($fields);
@@ -526,7 +526,7 @@ if (isset($_REQUEST['delete']) && isset($_REQUEST['itemid'])) {
 	}
 
 	if ($result) {
-		uncheckTableRows();
+		uncheckTableRows(getRequest('checkbox_hash'));
 	}
 	unset($_REQUEST['itemid'], $_REQUEST['form']);
 	show_messages($result, _('Item deleted'), _('Cannot delete item'));
@@ -936,7 +936,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 
 	if ($result) {
 		unset($_REQUEST['itemid'], $_REQUEST['form']);
-		uncheckTableRows();
+		uncheckTableRows(getRequest('checkbox_hash'));
 	}
 }
 elseif (hasRequest('check_now') && hasRequest('itemid')) {
@@ -1276,7 +1276,7 @@ elseif ($valid_input && hasRequest('massupdate') && hasRequest('group_itemid'))
 
 	if ($result) {
 		unset($_REQUEST['group_itemid'], $_REQUEST['massupdate'], $_REQUEST['form']);
-		uncheckTableRows();
+		uncheckTableRows(getRequest('checkbox_hash'));
 	}
 	show_messages($result, _('Items updated'), _('Cannot update items'));
 }
@@ -1292,7 +1292,7 @@ elseif (hasRequest('action') && str_in_array(getRequest('action'), ['item.massen
 	$result = (bool) API::Item()->update($items);
 
 	if ($result) {
-		uncheckTableRows();
+		uncheckTableRows(getRequest('checkbox_hash'));
 	}
 
 	$updated = count($itemids);
@@ -1337,7 +1337,7 @@ elseif (hasRequest('action') && getRequest('action') === 'item.masscopyto' && ha
 		$items_count = count(getRequest('group_itemid'));
 
 		if ($result) {
-			uncheckTableRows();
+			uncheckTableRows(getRequest('checkbox_hash'));
 			unset($_REQUEST['group_itemid']);
 		}
 		show_messages($result,
@@ -1382,7 +1382,7 @@ elseif (hasRequest('action') && getRequest('action') === 'item.massclearhistory'
 		$result = DBend($result);
 
 		if ($result) {
-			uncheckTableRows();
+			uncheckTableRows(getRequest('checkbox_hash'));
 		}
 	}
 
@@ -1394,7 +1394,7 @@ elseif (hasRequest('action') && getRequest('action') === 'item.massdelete' && ha
 	$result = API::Item()->delete($group_itemid);
 
 	if ($result) {
-		uncheckTableRows();
+		uncheckTableRows(getRequest('checkbox_hash'));
 	}
 	show_messages($result, _('Items deleted'), _('Cannot delete items'));
 }
@@ -1405,7 +1405,7 @@ elseif (hasRequest('action') && getRequest('action') === 'item.masscheck_now' &&
 	]);
 
 	if ($result) {
-		uncheckTableRows();
+		uncheckTableRows(getRequest('checkbox_hash'));
 	}
 
 	show_messages($result, _('Request sent successfully'), _('Cannot send request'));
@@ -1417,7 +1417,7 @@ if (hasRequest('action') && hasRequest('group_itemid') && !$result) {
 		'itemids' => getRequest('group_itemid'),
 		'editable' => true
 	]);
-	uncheckTableRows(null, zbx_objectValues($itemids, 'itemid'));
+	uncheckTableRows(getRequest('checkbox_hash'), zbx_objectValues($itemids, 'itemid'));
 }
 
 /*
@@ -2059,6 +2059,9 @@ else {
 
 	$data['trigger_parent_templates'] = getTriggerParentTemplates($data['itemTriggers'], ZBX_FLAG_DISCOVERY_NORMAL);
 
+	sort($filter_hostids);
+	$data['checkbox_hash'] = crc32(implode('', $filter_hostids));
+
 	// render view
 	$itemView = new CView('configuration.item.list', $data);
 	$itemView->render();
